==> reakit-system-bootstrap-0.1.0.tgz: package/src/Menu.ts <==
import { css, cx } from "emotion";
import { unstable_MenuProps, unstable_MenuOptions } from "reakit/Menu/Menu";
import {
  unstable_MenuDisclosureProps,
  unstable_MenuDisclosureOptions
} from "reakit/Menu/MenuDisclosure";
import {
  unstable_MenuItemCheckboxProps,
  unstable_MenuItemCheckboxOptions
} from "reakit/Menu/MenuItemCheckbox";
import {
  unstable_MenuItemDisclosureProps,
  unstable_MenuItemDisclosureOptions
} from "reakit/Menu/MenuItemDisclosure";
import {
  unstable_MenuItemRadioProps,
  unstable_MenuItemRadioOptions
} from "reakit/Menu/MenuItemRadio";
import {
  unstable_StaticMenuProps,
  unstable_StaticMenuOptions
} from "reakit/Menu/StaticMenu";
import { useContrast } from "reakit-system-palette/utils/contrast";
import { useDarken } from "reakit-system-palette/utils/darken";
import { usePalette } from "reakit-system-palette/utils/palette";
import { BootstrapBoxOptions } from "./Box";

export type BootstrapStaticMenuOptions = BootstrapBoxOptions &
  unstable_StaticMenuOptions;

export function useStaticMenuProps(
  { unstable_system, ...options }: BootstrapStaticMenuOptions,
  { className, ...htmlProps }: unstable_StaticMenuProps = {}
) {
  const primary = usePalette("primary") || "blue";
  const primaryContrast = useContrast(primary);
  const darkPrimary = useDarken(primary, 0.2);
  const isHorizontal = options.orientation === "horizontal";

  const staticMenu = css`
    display: flex;
    flex-direction: ${isHorizontal ? "row" : "column"};

    &[aria-orientation="vertical"] {
      padding: 0.25em 0;
    }

    &[aria-orientation="horizontal"] {
      padding: 0;
    }

    & > *:not(hr) {
      line-height: 1.5;
      padding: 0 ${isHorizontal ? "0.5em" : "1.5em"};
      text-align: left;
      border: 0;
      background-color: transparent;
      font-size: 100%;
      margin: 0;
      user-select: none;

      &:focus,
      &:focus-within,
      &:hover {
        background-color: ${primary};
        color: ${primaryContrast};
        box-shadow: none !important;
      }

      &:active {
        background-color: ${darkPrimary} !important;
      }
    }
  `;

  return { ...htmlProps, className: cx(className, staticMenu) };
}

export type BootstrapMenuOptions = BootstrapBoxOptions & unstable_MenuOptions;

export function useMenuOptions({
  unstable_system: { palette = "background", fill = "opaque", ...system } = {},
  ...options
}: BootstrapMenuOptions): BootstrapMenuOptions {
  return {
    unstable_system: { palette, fill, ...system },
    ...options
  };
}

export function useMenuProps(
  options: BootstrapMenuOptions,
  { className, ...htmlProps }: unstable_MenuProps = {}
) {
  const parentIsVertical =
    options.unstable_parent &&
    options.unstable_parent.orientation !== "horizontal";

  const menu = css`
    display: flex;
    border-radius: 0;

    ${parentIsVertical &&
      css`
        &[aria-orientation="vertical"] {
          margin-top: -0.3em;
        }
      `};
  `;

  return { ...htmlProps, className: cx(className, menu) };
}

export type BootstrapMenuDisclosureOptions = BootstrapBoxOptions &
  unstable_MenuDisclosureOptions;

export function useMenuDisclosureProps(
  options: BootstrapMenuDisclosureOptions,
  { className, ...htmlProps }: unstable_MenuDisclosureProps = {}
) {
  const parentIsHorizontal =
    options.unstable_parent &&
    options.unstable_parent.orientation === "horizontal";

  const dir = options.placement ? options.placement.split("-")[0] : undefined;

  const arrowMap: Record<string, any> = {
    top: "▲",
    right: "▶",
    bottom: "▼",
    left: "◀"
  };

  const menuDisclosure = css`
    position: relative;
    ${dir !== "left" &&
      !parentIsHorizontal &&
      css`
        padding-right: 1.6em;
      `};

    ${dir &&
      !parentIsHorizontal &&
      css`&:after {
      content: "${arrowMap[dir]}";
      position: absolute;
      font-size: 0.7em;
      line-height: inherit;
      padding: 0.42em 0;
      ${dir === "left" ? "left" : "right"}: 0.75em;
    }`}
  `;

  return { ...htmlProps, className: cx(className, menuDisclosure) };
}

export type BootstrapMenuItemCheckboxOptions = BootstrapBoxOptions &
  unstable_MenuItemCheckboxOptions;

export function useMenuItemCheckboxProps(
  _: BootstrapMenuItemCheckboxOptions,
  { className, ...htmlProps }: unstable_MenuItemCheckboxProps = {}
) {
  const menuItemCheckbox = css`
    appearance: none;
    margin: 0 0 0 -1.3em;
    width: 1em;
    height: 1em;
    color: inherit;
    outline: 0;

    &:checked {
      &:after {
        content: "✓";
      }
    }
  `;

  return { ...htmlProps, className: cx(className, menuItemCheckbox) };
}

export type BootstrapMenuItemDisclosureOptions = BootstrapBoxOptions &
  unstable_MenuItemDisclosureOptions;

export function useMenuItemDisclosureProps(
  _: BootstrapMenuItemDisclosureOptions,
  { className, ...htmlProps }: unstable_MenuItemDisclosureProps = {}
) {
  const primary = usePalette("primary") || "blue";
  const primaryContrast = useContrast(primary);

  const menuItemDisclosure = css`
    position: relative;
    line-height: 1.5;
    border-radius: 0;
    border: none;
    background: none;
    color: inherit;
    cursor: auto;
    transition: none;

    &:focus,
    &:hover,
    &[aria-expanded="true"] {
      background-color: ${primary};
      color: ${primaryContrast};
      box-shadow: none;
    }
  `;

  return { ...htmlProps, className: cx(className, menuItemDisclosure) };
}

export type BootstrapMenuItemRadioOptions = BootstrapBoxOptions &
  unstable_MenuItemRadioOptions;

export function useMenuItemRadioProps(
  _: BootstrapMenuItemRadioOptions,
  { className, ...htmlProps }: unstable_MenuItemRadioProps = {}
) {
  const menuItemRadio = css`
    appearance: none;
    margin: 0 0.3em 0 -1.3em;
    width: 1em;
    height: 1em;
    color: inherit;
    outline: 0;

    &:checked {
      &:after {
        content: "•";
        font-size: 1.5em;
      }
    }
  `;

  return { ...htmlProps, className: cx(className, menuItemRadio) };
}

==> reakit-system-bootstrap-0.1.1.tgz: package/src/Menu.ts <==
import { css, cx } from "emotion";
import { MenuProps, MenuOptions } from "reakit/Menu/Menu";
import {
  MenuDisclosureProps,
  MenuDisclosureOptions
} from "reakit/Menu/MenuDisclosure";
import {
  MenuItemCheckboxProps,
  MenuItemCheckboxOptions
} from "reakit/Menu/MenuItemCheckbox";
import {
  MenuItemRadioProps,
  MenuItemRadioOptions
} from "reakit/Menu/MenuItemRadio";
import { StaticMenuProps, StaticMenuOptions } from "reakit/Menu/StaticMenu";
import { MenuItemOptions, MenuItemProps } from "reakit/Menu/MenuItem";
import { useContrast } from "reakit-system-palette/utils/contrast";
import { useDarken } from "reakit-system-palette/utils/darken";
import { usePalette } from "reakit-system-palette/utils/palette";
import { BootstrapBoxOptions } from "./Box";

export type BootstrapStaticMenuOptions = BootstrapBoxOptions &
  StaticMenuOptions;

export function useStaticMenuProps(
  options: BootstrapStaticMenuOptions,
  { className, ...htmlProps }: StaticMenuProps = {}
) {
  const isHorizontal = options.orientation === "horizontal";

  const staticMenu = css`
    display: flex;
    flex-direction: ${isHorizontal ? "row" : "column"};
    white-space: nowrap;

    &[aria-orientation="vertical"] {
      padding: 0.25em 0;
    }

    &[aria-orientation="horizontal"] {
      padding: 0;
    }
  `;

  return { ...htmlProps, className: cx(className, staticMenu) };
}

export type BootstrapMenuItemOptions = BootstrapBoxOptions & MenuItemOptions;

export function useMenuItemProps(
  { unstable_system, ...options }: BootstrapMenuItemOptions,
  { className, ...htmlProps }: MenuItemProps = {}
) {
  const foreground = usePalette("foreground") || "black";
  const primary = usePalette("primary") || "blue";
  const primaryContrast = useContrast(primary);
  const darkPrimary = useDarken(primary, 0.2);
  const isHorizontal = options.orientation === "horizontal";

  const menuItem = css`
    &&& {
      line-height: 1.5;
      padding: 0 ${isHorizontal ? "0.5em" : "1.5em"};
      text-align: left;
      border: 0;
      border-radius: 0;
      font-size: 100%;
      background: transparent;
      color: ${foreground};
      margin: 0;
      user-select: none;

      &:focus,
      &[aria-expanded="true"] {
        background-color: ${primary};
        color: ${primaryContrast};
        box-shadow: none !important;
      }

      &:active {
        background-color: ${darkPrimary} !important;
      }
    }
  `;

  return { ...htmlProps, className: cx(className, menuItem) };
}

export type BootstrapMenuOptions = BootstrapBoxOptions & MenuOptions;

export function useMenuOptions({
  unstable_system: { palette = "background", fill = "opaque", ...system } = {},
  ...options
}: BootstrapMenuOptions): BootstrapMenuOptions {
  return {
    unstable_system: { palette, fill, ...system },
    ...options
  };
}

export function useMenuProps(
  _: BootstrapMenuOptions,
  { className, ...htmlProps }: MenuProps = {}
) {
  const menu = css`
    display: flex;
    border-radius: 0;

    &:not([aria-orientation="horizontal"]) > &[aria-orientation="vertical"] {
      margin-top: -0.3em;
    }
  `;

  return { ...htmlProps, className: cx(className, menu) };
}

export type BootstrapMenuDisclosureOptions = BootstrapBoxOptions &
  MenuDisclosureOptions;

export function useMenuDisclosureProps(
  options: BootstrapMenuDisclosureOptions,
  { className, ...htmlProps }: MenuDisclosureProps = {}
) {
  const dir = options.placement ? options.placement.split("-")[0] : undefined;

  const arrowMap: Record<string, any> = {
    top: "▲",
    right: "▶",
    bottom: "▼",
    left: "◀"
  };

  const menuDisclosure = css`
    position: relative;

    *:not([aria-orientation="horizontal"]) > & {
      ${dir !== "left" &&
        css`
          padding-right: 1.6em;
        `}
      ${dir &&
        css`
      &:after {
      content: "${arrowMap[dir]}";
      position: absolute;
      font-size: 0.7em;
      line-height: inherit;
      padding: 0.42em 0;
      ${dir === "left" ? "left" : "right"}: 0.75em;
    }`}
    }
  `;

  return { ...htmlProps, className: cx(className, menuDisclosure) };
}

export type BootstrapMenuItemCheckboxOptions = BootstrapBoxOptions &
  MenuItemCheckboxOptions;

export function useMenuItemCheckboxProps(
  _: BootstrapMenuItemCheckboxOptions,
  { className, ...htmlProps }: MenuItemCheckboxProps = {}
) {
  const menuItemCheckbox = css`
    position: relative;
    outline: 0;

    &[aria-checked="true"] {
      &:before {
        content: "✓";
        position: absolute;
        top: 0;
        left: 0.4em;
        width: 1em;
        height: 1em;
      }
    }
  `;

  return { ...htmlProps, className: cx(className, menuItemCheckbox) };
}

export type BootstrapMenuItemRadioOptions = BootstrapBoxOptions &
  MenuItemRadioOptions;

export function useMenuItemRadioProps(
  _: BootstrapMenuItemRadioOptions,
  { className, ...htmlProps }: MenuItemRadioProps = {}
) {
  const menuItemRadio = css`
    position: relative;
    outline: 0;

    &[aria-checked="true"] {
      &:before {
        content: "•";
        position: absolute;
        font-size: 1.4em;
        top: -0.25em;
        left: 0.3em;
        width: 0.7142857143em;
        height: 0.7142857143em;
      }
    }
  `;

  return { ...htmlProps, className: cx(className, menuItemRadio) };
}
